@@ -1,4 +1,4 @@
-// Copyright (C) 2021-2025 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2021-2026 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -59,8 +59,10 @@ DnsServer::DnsServer(const string& id, const set<string>& domains,
       rekey_interval_(DEFAULT_REKEY_INTERVAL),
       retry_interval_(DEFAULT_RETRY_INTERVAL), tkey_proto_(IOFetch::TCP),
       fallback_(false), exchange_timeout_(DEFAULT_EXCHANGE_TIMEOUT), timer_() {
-    BOOST_STATIC_ASSERT(DEFAULT_REKEY_INTERVAL < DEFAULT_KEY_LIFETIME);
-    BOOST_STATIC_ASSERT(DEFAULT_RETRY_INTERVAL < DEFAULT_REKEY_INTERVAL);
+    static_assert(DEFAULT_REKEY_INTERVAL < DEFAULT_KEY_LIFETIME,
+                  "DEFAULT_REKEY_INTERVAL < DEFAULT_KEY_LIFETIME");
+    static_assert(DEFAULT_RETRY_INTERVAL < DEFAULT_REKEY_INTERVAL,
+                  "DEFAULT_RETRY_INTERVAL < DEFAULT_REKEY_INTERVAL");
     initStats();
 }
 
@@ -294,6 +296,7 @@ const SimpleKeywords GssTsigCfg::GLOBAL_PARAMETERS = {
     { "retry-interval",     Element::integer },
     { "tkey-protocol",      Element::string },
     { "fallback",           Element::boolean },
+    { "exchange-timeout",   Element::integer },
     { "servers",            Element::list },
     { "user-context",       Element::map },
     { "comment",            Element::string }
@@ -695,7 +698,7 @@ GssTsigCfg::configure(ConstElementPtr params) {
             srv->setFallback(fallback->boolValue());
         }
 
-        ConstElementPtr tkey_timeout = params->get("exchange-timeout");
+        ConstElementPtr tkey_timeout = map->get("exchange-timeout");
         if (!tkey_timeout) {
             tkey_timeout = global_tkey_timeout;
         }
