@@ -43,6 +43,10 @@ extern const isc::log::MessageID MYSQL_LB_GET_RELAYID4 = "MYSQL_LB_GET_RELAYID4"
 extern const isc::log::MessageID MYSQL_LB_GET_RELAYID6 = "MYSQL_LB_GET_RELAYID6";
 extern const isc::log::MessageID MYSQL_LB_GET_REMOTEID4 = "MYSQL_LB_GET_REMOTEID4";
 extern const isc::log::MessageID MYSQL_LB_GET_REMOTEID6 = "MYSQL_LB_GET_REMOTEID6";
+extern const isc::log::MessageID MYSQL_LB_GET_STATE4 = "MYSQL_LB_GET_STATE4";
+extern const isc::log::MessageID MYSQL_LB_GET_STATE6 = "MYSQL_LB_GET_STATE6";
+extern const isc::log::MessageID MYSQL_LB_GET_STATE_SUBID4 = "MYSQL_LB_GET_STATE_SUBID4";
+extern const isc::log::MessageID MYSQL_LB_GET_STATE_SUBID6 = "MYSQL_LB_GET_STATE_SUBID6";
 extern const isc::log::MessageID MYSQL_LB_GET_SUBID4 = "MYSQL_LB_GET_SUBID4";
 extern const isc::log::MessageID MYSQL_LB_GET_SUBID6 = "MYSQL_LB_GET_SUBID6";
 extern const isc::log::MessageID MYSQL_LB_GET_SUBID_CLIENTID = "MYSQL_LB_GET_SUBID_CLIENTID";
@@ -104,6 +108,10 @@ const char* values[] = {
     "MYSQL_LB_GET_RELAYID6", "obtaining at most %1 IPv6 leases starting from address %2 with relay id %3",
     "MYSQL_LB_GET_REMOTEID4", "obtaining at most %1 IPv4 leases starting from address %2 with remote id %3 and cltt between %4 and %5",
     "MYSQL_LB_GET_REMOTEID6", "obtaining at most %1 IPv6 leases starting from address %2 with remote id %3",
+    "MYSQL_LB_GET_STATE4", "obtaining IPv4 leases with state %1",
+    "MYSQL_LB_GET_STATE6", "obtaining IPv6 leases with state %1",
+    "MYSQL_LB_GET_STATE_SUBID4", "obtaining IPv4 leases with state %1 in subnet %2",
+    "MYSQL_LB_GET_STATE_SUBID6", "obtaining IPv6 leases with state %1 in subnet %2",
     "MYSQL_LB_GET_SUBID4", "obtaining IPv4 leases for subnet ID %1",
     "MYSQL_LB_GET_SUBID6", "obtaining IPv6 leases for subnet ID %1",
     "MYSQL_LB_GET_SUBID_CLIENTID", "obtaining IPv4 lease for subnet ID %1 and client ID %2",
