@@ -317,6 +317,22 @@ public:
     getLeases4(const asiolink::IOAddress& lower_bound_address,
                const LeasePageSize& page_size) const override;
 
+    /// @brief Returns all IPv4 leases for the particular state and subnet.
+    ///
+    /// @param state the state e.g. 1 (declined).
+    /// @param subnet_id the subnet identifier (0 for all leases).
+    ///
+    /// @return Lease collection (may be empty if no IPv4 lease found).
+    virtual Lease4Collection getLeases4(uint32_t state,
+                                        SubnetID subnet_id) const override;
+
+    /// @brief Returns all IPv4 leases for the particular state.
+    ///
+    /// @param state the state e.g. 1 (declined).
+    ///
+    /// @return Lease collection (may be empty if no IPv4 lease found).
+    Lease4Collection getLeases4ByState(uint32_t state) const;
+
     /// @brief Returns existing IPv6 lease for a given IPv6 address.
     ///
     /// For a given address, we assume that there will be only one lease.
@@ -465,6 +481,22 @@ public:
                const asiolink::IOAddress& lower_bound_address,
                const LeasePageSize& page_size) const override;
 
+    /// @brief Returns all IPv6 leases for the particular state and subnet.
+    ///
+    /// @param state the state e.g. 1 (declined).
+    /// @param subnet_id the subnet identifier (0 for all leases).
+    ///
+    /// @return Lease collection (may be empty if no IPv6 lease found).
+    virtual Lease6Collection getLeases6(uint32_t state,
+                                        SubnetID subnet_id) const override;
+
+    /// @brief Returns all IPv6 leases for the particular state.
+    ///
+    /// @param state the state e.g. 1 (declined).
+    ///
+    /// @return Lease collection (may be empty if no IPv6 lease found).
+    Lease6Collection getLeases6ByState(uint32_t state) const;
+
     /// @brief Returns a collection of expired DHCPv4 leases.
     ///
     /// This method returns at most @c max_leases expired leases. The leases
@@ -762,6 +794,8 @@ public:
         GET_LEASE4_PAGE,             // Get page of leases beginning with an address
         GET_LEASE4_UCTX_PAGE,        // Get page of leases with user context
         GET_LEASE4_SUBID,            // Get IPv4 leases by subnet ID
+        GET_LEASE4_STATE,            // Get IPv4 leases by state
+        GET_LEASE4_STATE_SUBID,      // Get IPv4 leases by state & subnet ID
         GET_LEASE4_HOSTNAME,         // Get IPv4 leases by hostname
         GET_LEASE4_EXPIRE,           // Get lease4 by expiration.
         GET_LEASE4_RELAYID,          // Get page of lease by relay ID.
@@ -782,6 +816,8 @@ public:
         GET_LEASE6_SUBID,            // Get IPv6 leases by subnet ID
         GET_LEASE6_SUBID_PAGE,       // Get page of IPv6 leases by subnet ID
         GET_LEASE6_DUID,             // Get IPv6 leases by DUID
+        GET_LEASE6_STATE,            // Get IPv6 leases by state
+        GET_LEASE6_STATE_SUBID,      // Get IPv6 leases by state & subnet ID
         GET_LEASE6_HOSTNAME,         // Get IPv6 leases by hostname
         GET_LEASE6_EXPIRE,           // Get lease6 by expiration.
         INSERT_LEASE4,               // Add entry to lease4 table
