@@ -507,6 +507,17 @@ TEST_F(PgSqlLeaseMgrTest, getLeases4PagedMultiThreading) {
     testGetLeases4Paged();
 }
 
+/// @brief This test checks that all IPv4 leases with a state are returned.
+TEST_F(PgSqlLeaseMgrTest, getLeases4State) {
+    testGetLeases4State();
+}
+
+/// @brief This test checks that all IPv4 leases with a state are returned.
+TEST_F(PgSqlLeaseMgrTest, getLeases4StateMultiThreading) {
+    MultiThreadingTest mt(true);
+    testGetLeases4State();
+}
+
 /// @brief This test checks that all IPv6 leases for a specified subnet id are returned.
 TEST_F(PgSqlLeaseMgrTest, getLeases6SubnetId) {
     testGetLeases6SubnetId();
@@ -531,6 +542,17 @@ TEST_F(PgSqlLeaseMgrTest, getLeases6SubnetIdPagedMultiThreading) {
     testGetLeases6SubnetIdPaged();
 }
 
+/// @brief This test checks that all IPv6 leases with a state are returned.
+TEST_F(PgSqlLeaseMgrTest, getLeases6State) {
+    testGetLeases6State();
+}
+
+/// @brief This test checks that all IPv6 leases with a state are returned.
+TEST_F(PgSqlLeaseMgrTest, getLeases6StateMultiThreading) {
+    MultiThreadingTest mt(true);
+    testGetLeases6State();
+}
+
 /// @brief This test checks that all IPv6 leases with a specified hostname are returned.
 TEST_F(PgSqlLeaseMgrTest, getLeases6Hostname) {
     testGetLeases6Hostname();
@@ -1401,6 +1423,30 @@ TEST_F(PgSqlLeaseMgrTest, bigStats) {
     testBigStats();
 }
 
+TEST_F(PgSqlLeaseMgrTest, updateStatsOn4SameSubnet) {
+    testUpdateStatsOn4SameSubnet();
+}
+
+TEST_F(PgSqlLeaseMgrTest, updateStatsOn4DifferentSubnet) {
+    testUpdateStatsOn4DifferentSubnet();
+}
+
+TEST_F(PgSqlLeaseMgrTest, updateStatsOn6SameSubnet) { 
+    testUpdateStatsOn6SameSubnet();
+}
+
+TEST_F(PgSqlLeaseMgrTest, updateStatsOn6SameSubnetPD) { 
+    testUpdateStatsOn6SameSubnetPD();
+}
+
+TEST_F(PgSqlLeaseMgrTest, updateStatsOn6DifferentSubnet) { 
+    testUpdateStatsOn6DifferentSubnet();
+}
+
+TEST_F(PgSqlLeaseMgrTest, updateStatsOn6DifferentSubnetPD) { 
+    testUpdateStatsOn6DifferentSubnetPD();
+}
+
 /// @brief Test fixture class for testing @ref CfgDbAccessTest using PostgreSQL
 /// backend.
 class CfgPgSqlLbDbAccessTest : public ::testing::Test {
