@@ -1,4 +1,4 @@
-// Copyright (C) 2011-2025 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2011-2026 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -10,6 +10,8 @@
 #include <asiolink/udp_endpoint.h>
 #include <dhcp/dhcp4.h>
 #include <dhcp/dhcp6.h>
+#include <dhcp/dhcp_log.h>
+#include <dhcp/dhcp_messages.h>
 #include <dhcp/iface_mgr.h>
 #include <dhcp/iface_mgr_error_handler.h>
 #include <dhcp/pkt_filter_inet.h>
@@ -178,7 +180,7 @@ bool Iface::delSocket(const uint16_t sockfd) {
 IfaceMgr::IfaceMgr()
     : packet_filter_(new PktFilterInet()),
       packet_filter6_(new PktFilterInet6()),
-      test_mode_(false), allow_loopback_(false) {
+      test_mode_(false), check_thread_id_(true), allow_loopback_(false) {
     id_ = std::this_thread::get_id();
 
     // Ensure that PQMs have been created to guarantee we have
@@ -332,26 +334,28 @@ IfaceMgr::addExternalSocket(int socketfd, SocketCallback callback) {
         isc_throw(BadValue, "Attempted to install callback for invalid socket "
                   << socketfd);
     }
-    // @todo: remove comment when exclusively allow external sockets actions on main thread.
-    //if (std::this_thread::get_id() != id_) {
-    //    isc_throw(InvalidOperation, "Attempted to register external socket from different thread "
-    //              << std::this_thread::get_id());
-    //}
+    if (check_thread_id_ && std::this_thread::get_id() != id_) {
+        LOG_ERROR(dhcp_logger, DHCP_ADD_EXTERNAL_SOCKET_BAD_THREAD)
+            .arg(socketfd)
+            .arg(std::this_thread::get_id())
+            .arg(id_);
+    }
+    // New entry.
+    SocketCallbackInfo x(socketfd);
+    x.callback_ = callback;
     std::lock_guard<std::mutex> lock(callbacks_mutex_);
-    for (SocketCallbackInfo& s : callbacks_) {
+    auto& idx = callbacks_.get<1>();
+    auto it = idx.find(socketfd);
+    if (it != idx.end()) {
         // There's such a socket description there already.
-        // Update the callback and we're done
-        if (s.socket_ == socketfd) {
-            s.callback_ = callback;
-            s.unusable_ = false;
-            return;
-        }
+        // Replace it.
+        LOG_WARN(dhcp_logger, DHCP_ADD_EXTERNAL_SOCKET_ALREADY_EXISTS)
+            .arg(socketfd);
+        idx.replace(it, x);
+        return;
     }
 
     // Add a new entry to the callbacks vector
-    SocketCallbackInfo x;
-    x.socket_ = socketfd;
-    x.callback_ = callback;
     callbacks_.push_back(x);
 }
 
@@ -363,39 +367,37 @@ IfaceMgr::deleteExternalSocket(int socketfd) {
 
 void
 IfaceMgr::deleteExternalSocketInternal(int socketfd) {
-    // @todo: remove comment when exclusively allow external sockets actions on main thread.
-    //if (std::this_thread::get_id() != id_) {
-    //    isc_throw(InvalidOperation, "Attempted to unregister external socket from different thread "
-    //              << std::this_thread::get_id());
-    //}
-    for (SocketCallbackInfoContainer::iterator s = callbacks_.begin();
-         s != callbacks_.end(); ++s) {
-        if (s->socket_ == socketfd) {
-            callbacks_.erase(s);
-            return;
-        }
+    if (check_thread_id_ && std::this_thread::get_id() != id_) {
+        LOG_ERROR(dhcp_logger, DHCP_DELETE_EXTERNAL_SOCKET_BAD_THREAD)
+            .arg(socketfd)
+            .arg(std::this_thread::get_id())
+            .arg(id_);
     }
+    auto& idx = callbacks_.get<1>();
+    auto it = idx.find(socketfd);
+    if (it == idx.end()) {
+        LOG_WARN(dhcp_logger, DHCP_DELETE_EXTERNAL_SOCKET_NOT_FOUND)
+            .arg(socketfd);
+        return;
+    }
+    idx.erase(it);
 }
 
 bool
 IfaceMgr::isExternalSocket(int fd) {
     std::lock_guard<std::mutex> lock(callbacks_mutex_);
-    for (const SocketCallbackInfo& s : callbacks_) {
-        if (s.socket_ == fd) {
-            return (true);
-        }
-    }
-
-    return (false);
+    auto const& idx = callbacks_.get<1>();
+    auto const it = idx.find(fd);
+    return (it != idx.end());
 }
 
 bool
 IfaceMgr::isExternalSocketUnusable(int fd) {
     std::lock_guard<std::mutex> lock(callbacks_mutex_);
-    for (const SocketCallbackInfo& s : callbacks_) {
-        if (s.socket_ == fd) {
-            return (s.unusable_);
-        }
+    auto const& idx = callbacks_.get<1>();
+    auto const it = idx.find(fd);
+    if (it != idx.end()) {
+        return (it->unusable_);
     }
 
     return (false);
@@ -403,11 +405,11 @@ IfaceMgr::isExternalSocketUnusable(int fd) {
 
 void
 IfaceMgr::deleteAllExternalSockets() {
-    // @todo: remove comment when exclusively allow external sockets actions on main thread.
-    //if (std::this_thread::get_id() != id_) {
-    //    isc_throw(InvalidOperation, "Attempted to unregister external sockets from different thread "
-    //              << std::this_thread::get_id());
-    //}
+    if (check_thread_id_ && std::this_thread::get_id() != id_) {
+        LOG_ERROR(dhcp_logger, DHCP_DELETE_ALL_EXTERNAL_SOCKETS_BAD_THREAD)
+            .arg(std::this_thread::get_id())
+            .arg(id_);
+    }
     std::lock_guard<std::mutex> lock(callbacks_mutex_);
     callbacks_.clear();
 }
@@ -919,35 +921,29 @@ IfaceMgr::clearBoundAddresses() {
 }
 
 void
-IfaceMgr::handleClosedExternalSocket(SocketCallbackInfo& s) {
+IfaceMgr::handleClosedExternalSocket(SocketCallbackInfoIterator it) {
     errno = 0;
-    if (fcntl(s.socket_, F_GETFD) < 0 && (errno == EBADF)) {
-        s.unusable_ = true;
-        isc_throw(SocketFDError, "unexpected state (closed) for fd: " << s.socket_);
+    if (fcntl(it->socket_, F_GETFD) < 0 && (errno == EBADF)) {
+        SocketCallbackInfo x(*it);
+        x.unusable_ = true;
+        callbacks_.replace(it, x);
+        isc_throw(SocketFDError, "unexpected state (closed) for fd: " << x.socket_);
     }
 }
 
 void
 IfaceMgr::handleClosedExternalSockets() {
-    bool found = false;
     std::lock_guard<std::mutex> lock(callbacks_mutex_);
-    for (SocketCallbackInfo& s : callbacks_) {
-        if (s.unusable_) {
+    for (auto it = callbacks_.begin(); it != callbacks_.end(); ++it) {
+        if (it->unusable_) {
             continue;
         }
-        errno = 0;
-        if (fcntl(s.socket_, F_GETFD) < 0 && (errno == EBADF)) {
-            s.unusable_ = true;
-            found = true;
-        }
-    }
-    if (found) {
-        isc_throw(SocketFDError, "unexpected state (closed) for external sockets");
+        handleClosedExternalSocket(it);
     }
 }
 
 void
-IfaceMgr::handleIfaceSocketError(const SocketInfo& s) {
+IfaceMgr::handleIfaceSocketError(const IfacePtr& iface, const SocketInfo& s) {
     int error = 0;
     socklen_t opt_size = sizeof(error);
     errno = 0;
@@ -961,8 +957,10 @@ IfaceMgr::handleIfaceSocketError(const SocketInfo& s) {
                   << s.sockfd_ << " - error: " << strerror(errno));
     }
     if (error > 0) {
-        isc_throw(SocketFDError, "socket error fd: " << s.sockfd_
-                  << " error: " << strerror(error));
+        LOG_ERROR(dhcp_logger, DHCP_IFACE_SOCKET_ERROR)
+            .arg(s.sockfd_)
+            .arg(iface->getFullName())
+            .arg(strerror(error));
     }
 }
 
@@ -1202,13 +1200,13 @@ Pkt4Ptr IfaceMgr::receive4Indirect(uint32_t timeout_sec, uint32_t timeout_usec /
     {
         std::lock_guard<std::mutex> lock(callbacks_mutex_);
         if (!callbacks_.empty()) {
-            for (SocketCallbackInfo& s : callbacks_) {
-                if (s.unusable_) {
+            for (auto it = callbacks_.begin(); it != callbacks_.end(); ++it) {
+                if (it->unusable_) {
                     continue;
                 }
-                handleClosedExternalSocket(s);
+                handleClosedExternalSocket(it);
                 // Add this socket to listening set
-                fd_event_handler_->add(s.socket_);
+                fd_event_handler_->add(it->socket_);
             }
         }
     }
@@ -1265,35 +1263,35 @@ Pkt4Ptr IfaceMgr::receive4Indirect(uint32_t timeout_sec, uint32_t timeout_usec /
         }
 
         // Let's find out which external socket has the data
-        SocketCallbackInfo ex_sock;
+        boost::scoped_ptr<SocketCallbackInfo> ex_sock;
         bool found = false;
         {
             std::lock_guard<std::mutex> lock(callbacks_mutex_);
-            for (SocketCallbackInfo& s : callbacks_) {
-                if (s.unusable_) {
+            for (auto it = callbacks_.begin(); it != callbacks_.end(); ++it) {
+                if (it->unusable_) {
                     continue;
                 }
-                handleClosedExternalSocket(s);
-                if (fd_event_handler_->readReady(s.socket_) ||
-                    fd_event_handler_->hasError(s.socket_)) {
+                handleClosedExternalSocket(it);
+                if (fd_event_handler_->readReady(it->socket_) ||
+                    fd_event_handler_->hasError(it->socket_)) {
                     found = true;
 
                     // something received over external socket
-                    if (s.callback_) {
+                    if (it->callback_) {
                         // Note the external socket to call its callback without
                         // the lock taken so it can be deleted.
-                        ex_sock = s;
+                        ex_sock.reset(new SocketCallbackInfo(*it));
                         break;
                     }
                 }
             }
         }
 
-        if (ex_sock.callback_) {
+        if (ex_sock && ex_sock->callback_) {
             // Calling the external socket's callback provides its service
             // layer access without integrating any specific features
             // in IfaceMgr
-            ex_sock.callback_(ex_sock.socket_);
+            ex_sock->callback_(ex_sock->socket_);
         }
         if (found) {
             return (Pkt4Ptr());
@@ -1316,8 +1314,6 @@ Pkt4Ptr IfaceMgr::receive4Direct(uint32_t timeout_sec, uint32_t timeout_usec /*
                   " one million microseconds");
     }
 
-    boost::scoped_ptr<SocketInfo> candidate;
-
     fd_event_handler_->clear();
 
     /// @todo: marginal performance optimization. We could create the set once
@@ -1339,13 +1335,13 @@ Pkt4Ptr IfaceMgr::receive4Direct(uint32_t timeout_sec, uint32_t timeout_usec /*
     {
         std::lock_guard<std::mutex> lock(callbacks_mutex_);
         if (!callbacks_.empty()) {
-            for (SocketCallbackInfo& s : callbacks_) {
-                if (s.unusable_) {
+            for (auto it = callbacks_.begin(); it != callbacks_.end(); ++it) {
+                if (it->unusable_) {
                     continue;
                 }
-                handleClosedExternalSocket(s);
+                handleClosedExternalSocket(it);
                 // Add this socket to listening set
-                fd_event_handler_->add(s.socket_);
+                fd_event_handler_->add(it->socket_);
             }
         }
     }
@@ -1376,35 +1372,35 @@ Pkt4Ptr IfaceMgr::receive4Direct(uint32_t timeout_sec, uint32_t timeout_usec /*
     }
 
     // Let's find out which socket has the data
-    SocketCallbackInfo ex_sock;
+    boost::scoped_ptr<SocketCallbackInfo> ex_sock;
     bool found = false;
     {
         std::lock_guard<std::mutex> lock(callbacks_mutex_);
-        for (SocketCallbackInfo& s : callbacks_) {
-            if (s.unusable_) {
+        for (auto it = callbacks_.begin(); it != callbacks_.end(); ++it) {
+            if (it->unusable_) {
                 continue;
             }
-            handleClosedExternalSocket(s);
-            if (fd_event_handler_->readReady(s.socket_) ||
-                fd_event_handler_->hasError(s.socket_)) {
+            handleClosedExternalSocket(it);
+            if (fd_event_handler_->readReady(it->socket_) ||
+                fd_event_handler_->hasError(it->socket_)) {
                 found = true;
 
                 // something received over external socket
-                if (s.callback_) {
+                if (it->callback_) {
                     // Note the external socket to call its callback without
                     // the lock taken so it can be deleted.
-                    ex_sock = s;
+                    ex_sock.reset(new SocketCallbackInfo(*it));
                     break;
                 }
             }
         }
     }
 
-    if (ex_sock.callback_) {
+    if (ex_sock && ex_sock->callback_) {
         // Calling the external socket's callback provides its service
         // layer access without integrating any specific features
         // in IfaceMgr
-        ex_sock.callback_(ex_sock.socket_);
+        ex_sock->callback_(ex_sock->socket_);
     }
     if (found) {
         return (Pkt4Ptr());
@@ -1412,6 +1408,7 @@ Pkt4Ptr IfaceMgr::receive4Direct(uint32_t timeout_sec, uint32_t timeout_usec /*
 
     // Let's find out which interface/socket has the data
     // @todo: fix iface starvation
+    boost::scoped_ptr<SocketInfo> candidate;
     IfacePtr recv_if;
     for (const IfacePtr& iface : ifaces_) {
         for (const SocketInfo& s : iface->getSockets()) {
@@ -1420,7 +1417,7 @@ Pkt4Ptr IfaceMgr::receive4Direct(uint32_t timeout_sec, uint32_t timeout_usec /*
                 continue;
             }
             if (fd_event_handler_->hasError(s.sockfd_)) {
-                handleIfaceSocketError(s);
+                handleIfaceSocketError(iface, s);
             }
             candidate.reset(new SocketInfo(s));
             break;
@@ -1432,7 +1429,8 @@ Pkt4Ptr IfaceMgr::receive4Direct(uint32_t timeout_sec, uint32_t timeout_usec /*
     }
 
     if (!candidate || !recv_if) {
-        isc_throw(SocketFDError, "received data over unknown socket");
+        LOG_WARN(dhcp_logger, DHCP_RECEIVE4_UNKNOWN);
+        return (Pkt4Ptr());
     }
 
     // Check that we have something to read.
@@ -1466,8 +1464,6 @@ IfaceMgr::receive6Direct(uint32_t timeout_sec, uint32_t timeout_usec /* = 0 */ )
                   " one million microseconds");
     }
 
-    boost::scoped_ptr<SocketInfo> candidate;
-
     fd_event_handler_->clear();
 
     /// @todo: marginal performance optimization. We could create the set once
@@ -1489,13 +1485,13 @@ IfaceMgr::receive6Direct(uint32_t timeout_sec, uint32_t timeout_usec /* = 0 */ )
     {
         std::lock_guard<std::mutex> lock(callbacks_mutex_);
         if (!callbacks_.empty()) {
-            for (SocketCallbackInfo& s : callbacks_) {
-                if (s.unusable_) {
+            for (auto it = callbacks_.begin(); it != callbacks_.end(); ++it) {
+                if (it->unusable_) {
                     continue;
                 }
-                handleClosedExternalSocket(s);
+                handleClosedExternalSocket(it);
                 // Add this socket to listening set
-                fd_event_handler_->add(s.socket_);
+                fd_event_handler_->add(it->socket_);
             }
         }
     }
@@ -1526,35 +1522,35 @@ IfaceMgr::receive6Direct(uint32_t timeout_sec, uint32_t timeout_usec /* = 0 */ )
     }
 
     // Let's find out which socket has the data
-    SocketCallbackInfo ex_sock;
+    boost::scoped_ptr<SocketCallbackInfo> ex_sock;
     bool found = false;
     {
         std::lock_guard<std::mutex> lock(callbacks_mutex_);
-        for (SocketCallbackInfo& s : callbacks_) {
-            if (s.unusable_) {
+        for (auto it = callbacks_.begin(); it != callbacks_.end(); ++it) {
+            if (it->unusable_) {
                 continue;
             }
-            handleClosedExternalSocket(s);
-            if (fd_event_handler_->readReady(s.socket_) ||
-                fd_event_handler_->hasError(s.socket_)) {
+            handleClosedExternalSocket(it);
+            if (fd_event_handler_->readReady(it->socket_) ||
+                fd_event_handler_->hasError(it->socket_)) {
                 found = true;
 
                 // something received over external socket
-                if (s.callback_) {
+                if (it->callback_) {
                     // Note the external socket to call its callback without
                     // the lock taken so it can be deleted.
-                    ex_sock = s;
+                    ex_sock.reset(new SocketCallbackInfo(*it));
                     break;
                 }
             }
         }
     }
 
-    if (ex_sock.callback_) {
+    if (ex_sock && ex_sock->callback_) {
         // Calling the external socket's callback provides its service
         // layer access without integrating any specific features
         // in IfaceMgr
-        ex_sock.callback_(ex_sock.socket_);
+        ex_sock->callback_(ex_sock->socket_);
     }
     if (found) {
         return (Pkt6Ptr());
@@ -1562,6 +1558,7 @@ IfaceMgr::receive6Direct(uint32_t timeout_sec, uint32_t timeout_usec /* = 0 */ )
 
     // Let's find out which interface/socket has the data
     // @todo: fix iface starvation
+    boost::scoped_ptr<SocketInfo> candidate;
     for (const IfacePtr& iface : ifaces_) {
         for (const SocketInfo& s : iface->getSockets()) {
             if (!fd_event_handler_->readReady(s.sockfd_) &&
@@ -1569,7 +1566,7 @@ IfaceMgr::receive6Direct(uint32_t timeout_sec, uint32_t timeout_usec /* = 0 */ )
                 continue;
             }
             if (fd_event_handler_->hasError(s.sockfd_)) {
-                handleIfaceSocketError(s);
+                handleIfaceSocketError(iface, s);
             }
             candidate.reset(new SocketInfo(s));
             break;
@@ -1580,7 +1577,8 @@ IfaceMgr::receive6Direct(uint32_t timeout_sec, uint32_t timeout_usec /* = 0 */ )
     }
 
     if (!candidate) {
-        isc_throw(SocketFDError, "received data over unknown socket");
+        LOG_WARN(dhcp_logger, DHCP_RECEIVE6_UNKNOWN);
+        return (Pkt6Ptr());
     }
 
     // Check that we have something to read.
@@ -1611,13 +1609,13 @@ IfaceMgr::receive6Indirect(uint32_t timeout_sec, uint32_t timeout_usec /* = 0 */
     {
         std::lock_guard<std::mutex> lock(callbacks_mutex_);
         if (!callbacks_.empty()) {
-            for (SocketCallbackInfo& s : callbacks_) {
-                if (s.unusable_) {
+            for (auto it = callbacks_.begin(); it != callbacks_.end(); ++it) {
+                if (it->unusable_) {
                     continue;
                 }
-                handleClosedExternalSocket(s);
+                handleClosedExternalSocket(it);
                 // Add this socket to listening set
-                fd_event_handler_->add(s.socket_);
+                fd_event_handler_->add(it->socket_);
             }
         }
     }
@@ -1674,35 +1672,35 @@ IfaceMgr::receive6Indirect(uint32_t timeout_sec, uint32_t timeout_usec /* = 0 */
         }
 
         // Let's find out which external socket has the data
-        SocketCallbackInfo ex_sock;
+        boost::scoped_ptr<SocketCallbackInfo> ex_sock;
         bool found = false;
         {
             std::lock_guard<std::mutex> lock(callbacks_mutex_);
-            for (SocketCallbackInfo& s : callbacks_) {
-                if (s.unusable_) {
+            for (auto it = callbacks_.begin(); it != callbacks_.end(); ++it) {
+                if (it->unusable_) {
                     continue;
                 }
-                handleClosedExternalSocket(s);
-                if (fd_event_handler_->readReady(s.socket_) ||
-                    fd_event_handler_->hasError(s.socket_)) {
+                handleClosedExternalSocket(it);
+                if (fd_event_handler_->readReady(it->socket_) ||
+                    fd_event_handler_->hasError(it->socket_)) {
                     found = true;
 
                     // something received over external socket
-                    if (s.callback_) {
+                    if (it->callback_) {
                         // Note the external socket to call its callback without
                         // the lock taken so it can be deleted.
-                        ex_sock = s;
+                        ex_sock.reset(new SocketCallbackInfo(*it));
                         break;
                     }
                 }
             }
         }
 
-        if (ex_sock.callback_) {
+        if (ex_sock && ex_sock->callback_) {
             // Calling the external socket's callback provides its service
             // layer access without integrating any specific features
             // in IfaceMgr
-            ex_sock.callback_(ex_sock.socket_);
+            ex_sock->callback_(ex_sock->socket_);
         }
         if (found) {
             return (Pkt6Ptr());
@@ -1778,7 +1776,7 @@ IfaceMgr::receiveDHCP4Packets() {
                         continue;
                     }
                     if (receiver_fd_event_handler_->hasError(s.sockfd_)) {
-                        handleIfaceSocketError(s);
+                        handleIfaceSocketError(iface, s);
                     }
                     receiveDHCP4Packet(*iface, s);
                     // Can take time so check one more time the watch socket.
@@ -1855,7 +1853,7 @@ IfaceMgr::receiveDHCP6Packets() {
                         continue;
                     }
                     if (receiver_fd_event_handler_->hasError(s.sockfd_)) {
-                        handleIfaceSocketError(s);
+                        handleIfaceSocketError(iface, s);
                     }
                     receiveDHCP6Packet(s);
                     // Can take time so check one more time the watch socket.
