@@ -1,4 +1,4 @@
-// Copyright (C) 2011-2025 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2011-2026 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -22,6 +22,7 @@
 #include <util/watched_thread.h>
 
 #include <boost/multi_index/hashed_index.hpp>
+#include <boost/multi_index/member.hpp>
 #include <boost/multi_index/mem_fun.hpp>
 #include <boost/multi_index/sequenced_index.hpp>
 #include <boost/multi_index_container.hpp>
@@ -29,6 +30,7 @@
 #include <boost/scoped_array.hpp>
 #include <boost/shared_ptr.hpp>
 
+#include <atomic>
 #include <functional>
 #include <list>
 #include <mutex>
@@ -707,12 +709,36 @@ public:
         bool unusable_;
 
         /// @brief Constructor.
-        SocketCallbackInfo() : socket_(-1), unusable_(false) {
+        ///
+        /// @param socket The socket descriptor.
+        SocketCallbackInfo(int socket)
+            : socket_(socket), callback_(0), unusable_(false) {
         }
     };
 
     /// Defines storage container for callbacks for external sockets
-    typedef std::list<SocketCallbackInfo> SocketCallbackInfoContainer;
+    ///
+    /// This container extends a std::list with a second index which
+    /// provides direct access using the file descriptor.
+    typedef boost::multi_index_container<
+        // Container comprises elements of SocketCallbackInfo type.
+        SocketCallbackInfo,
+        // Here we start enumerating various indexes.
+        boost::multi_index::indexed_by<
+            // Sequenced index allows accessing elements in the same way
+            // as elements in std::list. Sequenced is the index #0.
+            boost::multi_index::sequenced<>,
+            // Use the file descriptor as the key for index #1.
+            boost::multi_index::hashed_unique<
+                boost::multi_index::member<
+                    SocketCallbackInfo, int, &SocketCallbackInfo::socket_
+                >
+            >
+        >
+    > SocketCallbackInfoContainer;
+
+    /// @brief SocketCallbackInfo iterator type.
+    typedef SocketCallbackInfoContainer::iterator SocketCallbackInfoIterator;
 
     /// @brief Packet reception buffer size
     ///
@@ -769,6 +795,23 @@ public:
         return (test_mode_);
     }
 
+    /// @brief Get the flag which indicates if thread ID is checked when
+    /// performing operations with external sockets.
+    ///
+    /// @return true if the @c IfaceMgr checks thread ID, false otherwise.
+    bool getCheckThreadId() const {
+        return (check_thread_id_);
+    }
+
+    /// @brief Set the flag which indicates if thread ID is checked when
+    /// performing operations with external sockets.
+    ///
+    /// @param check A flag which indicates if thread ID is checked when
+    /// performing operations with external sockets.
+    void setCheckThreadId(const bool check) {
+        check_thread_id_ = check;
+    }
+
     /// @brief Allows or disallows the loopback interface
     ///
     /// By default the loopback interface is not considered when opening
@@ -1192,6 +1235,17 @@ public:
     ///
     /// @param socketfd socket descriptor
     /// @param callback callback function
+    ///
+    /// @note: all operations on external sockets should be performed
+    /// from the main thread as it does not make sense (and does not
+    /// work as expected) to use an external socket which is in fact
+    /// managed by an I/O service of a thread pool. For instance
+    /// a new external socket is scanned by select or poll only after
+    /// the next call to the receive method. Same argument applies
+    /// when an external socket is deleted and closed...
+    ///
+    /// @note: the callback is called when read available, hup and
+    /// error conditions: the callback is assumed to not block.
     void addExternalSocket(int socketfd, SocketCallback callback);
 
     /// @brief Checks if socket's file description is registered.
@@ -1215,6 +1269,8 @@ public:
 
     /// @brief Deletes all external sockets.
     ///
+    /// @note: to be used only in unit tests.
+    ///
     /// External sockets should be removed from IfaceMgr before being closed
     /// by the external API.
     void deleteAllExternalSockets();
@@ -1627,16 +1683,20 @@ private:
 
     /// @brief Handle closed external socket.
     ///
-    /// @param s The external socket info.
-    void handleClosedExternalSocket(SocketCallbackInfo& s);
+    /// @note: the caller must take the lock when it generates
+    /// the argument and calls this method.
+    ///
+    /// @param it The external socket info iterator.
+    void handleClosedExternalSocket(SocketCallbackInfoIterator it);
 
     /// @brief Handle closed external sockets.
     void handleClosedExternalSockets();
 
     /// @brief Handle interface socket error.
     ///
+    /// @param iface The interface.
     /// @param s The interface socket info.
-    void handleIfaceSocketError(const SocketInfo& s);
+    void handleIfaceSocketError(const IfacePtr& iface, const SocketInfo& s);
 
     /// Holds instance of a class derived from PktFilter, used by the
     /// IfaceMgr to open sockets and send/receive packets through these
@@ -1663,6 +1723,9 @@ private:
     /// @brief Indicates if the IfaceMgr is in the test mode.
     bool test_mode_;
 
+    /// Check thread ID when performing operations with external sockets.
+    std::atomic<bool> check_thread_id_;
+
     /// @brief Detect callback used to perform actions before system dependent
     /// function calls.
     ///
