@@ -1,4 +1,4 @@
-// Copyright (C) 2021-2025 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2021-2026 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -105,6 +105,13 @@ setUmask() {
     }
 }
 
+RelaxUmask::RelaxUmask() : orig_umask_(umask(S_IRWXO)) {
+}
+
+RelaxUmask::~RelaxUmask() {
+    static_cast<void>(umask(orig_umask_));
+}
+
 bool amRunningAsRoot() {
     return (getuid() == 0 || geteuid() == 0);
 }
